@@ -3,6 +3,7 @@ from django import forms
 from django.utils.translation import ugettext_lazy as _, gettext
 from django.conf import settings
 from django.utils.html import format_html
+from django.utils.safestring import mark_safe
 
 from parler.admin import TranslatableAdmin
 from parler.forms import TranslatableModelForm
@@ -53,6 +54,7 @@ class TemplateAdmin(TranslatableAdmin):
     list_display = ['event', 'subject']
     form = TemplateForm
     add_form = AddTemplateForm
+    readonly_fields = ['read_tilda_html', 'tilda_html']
     fieldsets = (
         (None, {
             'fields': [
@@ -78,7 +80,8 @@ class TemplateAdmin(TranslatableAdmin):
         }),
         (_('Integrations'), {
             'fields': [
-                'tilda_id'
+                'tilda_id',
+                'read_tilda_html',
             ]
         })
     )
@@ -90,6 +93,10 @@ class TemplateAdmin(TranslatableAdmin):
         }),
     )
 
+    def read_tilda_html(self, obj):
+        return mark_safe(obj.tilda_html)
+    read_tilda_html.short_description = _('Tilda HTML')
+
     def get_fieldsets(self, request, obj=None):
         if not obj:
             return self.add_fieldsets
