@@ -1,11 +1,12 @@
 from django.conf import settings
-from django.urls import path
+from django.urls import path, include
 from django.contrib.staticfiles.urls import static
 from django.contrib import admin
 
 
 urlpatterns = [
     path('admin/', admin.site.urls),
+    path('', include('postie.integrations.tilda.urls'))
 ]
 
 if settings.DEBUG:
